@@ -64,9 +64,11 @@ use crate::experimental::AsifBytes;
 /// a number of bytes and writes to I/O.  The type of the value(s) can
 /// be explicitly specified as the generic type parameter of its
 /// method or simply omitted because the Rust compiler can infer from
-/// the argument.  The endianness of resulting value(s) is flipped
-/// when required and necessary.  Currently, only an implementation
-/// for trait `std::io::Write` is provided.
+/// the argument.  The methods whose name contain 's' (= slice) or 'v'
+/// (= vector) `decast` to a series of structured binary data.  The
+/// methods whose names end with 'f' flip the endianness of the
+/// results.  Currently, only an implementation for trait
+/// `std::io::Write` is provided.
 ///
 /// The output `self` should have enough room to encode to the
 /// specified number of value(s) of the specified type `T`.  If there
@@ -142,17 +144,36 @@ pub trait DecastIO {
     where
 	T: Cast + Flip;
 
-    /// Encodes the slice of value(s) of type `T` pointed by `slice`
-    /// to bytes and writes them to output `self`.  The endianness of
-    /// the resulting bytes is not flipped.
+    /// Encodes value(s) in `slice` of type `T` to bytes and writes
+    /// them to output `self`.  The endianness of the resulting bytes
+    /// is not flipped.
+    fn decasts<T>(&mut self, slice: &[T]) -> Result<usize>
+    where
+	T: Cast;
+
+    /// Encodes value(s) in `slice` of type `T` to bytes and writes
+    /// them to output `self`.  The endianness of the resulting bytes
+    /// is flipped if necessary.  The endianness of the resulting
+    /// bytes is specified in `endian`.
+    fn decastsf<T>(&mut self, slice: &[T], endian: Endian) -> Result<usize>
+    where
+	T: Cast + Flip;
+
+    /// Encodes value(s) in `slice` of type `T` to bytes and writes
+    /// them to output `self`.  The endianness of the resulting bytes
+    /// is not flipped.
+    /// (This method is replaced by `decasts`)
+    #[cfg(feature = "std")]
     fn decastv<T>(&mut self, slice: &[T]) -> Result<usize>
     where
 	T: Cast;
 
-    /// Encodes the slice of value(s) of type `T` pointed by `slice`
-    /// to bytes and writes them to output `self`.  The endianness of
-    /// the resulting bytes is flipped if necessary.  The endianness
-    /// of the resulting bytes is specified in `endian`.
+    /// Encodes value(s) in `slice` of type `T` to bytes and writes
+    /// them to output `self`.  The endianness of the resulting bytes
+    /// is flipped if necessary.  The endianness of the resulting
+    /// bytes is specified in `endian`.
+    /// (This method is replaced by `decastsf`)
+    #[cfg(feature = "std")]
     fn decastvf<T>(&mut self, slice: &[T], endian: Endian) -> Result<usize>
     where
 	T: Cast + Flip;
@@ -184,7 +205,7 @@ where
 	}
     }
 
-    fn decastv<T>(&mut self, slice: &[T]) -> Result<usize>
+    fn decasts<T>(&mut self, slice: &[T]) -> Result<usize>
     where
 	T: Cast
     {
@@ -194,12 +215,12 @@ where
 	Ok(mem::size_of::<T>() * slice.len())
     }
 
-    fn decastvf<T>(&mut self, slice: &[T], endian: Endian) -> Result<usize>
+    fn decastsf<T>(&mut self, slice: &[T], endian: Endian) -> Result<usize>
     where
 	T: Cast + Flip
     {
 	if !endian.need_swap() {
-	    self.decastv::<T>(slice)
+	    self.decasts::<T>(slice)
 	} else {
 	    for elem in slice {
 		self.decast::<T>(&elem.flip_val_swapped())?;
@@ -207,4 +228,20 @@ where
 	    Ok(mem::size_of::<T>() * slice.len())
 	}
     }
+
+    #[cfg(feature = "std")]
+    fn decastv<T>(&mut self, slice: &[T]) -> Result<usize>
+    where
+	T: Cast
+    {
+	self.decasts(slice)
+    }
+
+    #[cfg(feature = "std")]
+    fn decastvf<T>(&mut self, slice: &[T], endian: Endian) -> Result<usize>
+    where
+	T: Cast + Flip
+    {
+	self.decastsf(slice, endian)
+    }
 }
