@@ -1,3 +1,4 @@
+use core::option::Option::{self, Some};
 use core::{mem, ptr};
 
 use crate::{Cast, Endian, Flip};
@@ -58,9 +59,11 @@ use crate::{Cast, Endian, Flip};
 /// a number of bytes on memory.  The type of the value(s) may be
 /// explicitly specified as the generic type parameter of its methods
 /// or simply omitted because the Rust compiler can infer it from the
-/// argument.  The endianness of resulting bytes is flipped when
-/// required and necessary.  Currently, only an implementation for
-/// `[u8]` is provided.
+/// argument.  The methods whose name contain 's' (= slice) or 'v' (=
+/// vector) `decast` to a series of structured binary data.  The
+/// methods whose names end with 'f' flip the endianness of the
+/// results.  Currently, only an implementation for `[u8]` is
+/// provided.
 ///
 /// The size of `self` should be larger than or equal to the specified
 /// number of value(s) of the specified type `T`.  If there is enough
@@ -88,18 +91,36 @@ pub trait DecastMem {
     where
 	T: Cast + Flip;
 
-    /// Encodes the slice of value(s) of type `T` pointed by `slice`
-    /// to bytes and stores them at the head of `self`.  The
-    /// endianness of the resulting bytes is not flipped.
+    /// Encodes value(s) in `slice` of type `T` to bytes and stores
+    /// them at the head of `self`.  The endianness of the resulting
+    /// bytes is not flipped.
+    fn decasts<T>(&mut self, slice: &[T]) -> Option<usize>
+    where
+	T: Cast;
+
+    /// Encodes value(s) in `slice` of type `T` to bytes and stores
+    /// them at the head of `self`.  The endianness of the resulting
+    /// bytes is flipped if necessary.  The endianness of the
+    /// resulting bytes is specified in `endian`.
+    fn decastsf<T>(&mut self, slice: &[T], endian: Endian) -> Option<usize>
+    where
+	T: Cast + Flip;
+
+    /// Encodes value(s) in `slice` of type `T` to bytes and stores
+    /// them at the head of `self`.  The endianness of the resulting
+    /// bytes is not flipped.
+    /// (This method is replaced by `decasts`)
+    #[cfg(feature = "std")]
     fn decastv<T>(&mut self, slice: &[T]) -> Option<usize>
     where
 	T: Cast;
 
-    /// Encodes the slice of value(s) of type `T` pointed by `slice`
-    /// to bytes and stores them at the head of `self`.  The
-    /// endianness of the resulting bytes is flipped if necessary.
-    /// The endianness of the resulting bytes is specified in
-    /// `endian`.
+    /// Encodes value(s) in `slice` of type `T` to bytes and stores
+    /// them at the head of `self`.  The endianness of the resulting
+    /// bytes is flipped if necessary.  The endianness of the
+    /// resulting bytes is specified in `endian`.
+    /// (This method is replaced by `decastsf`)
+    #[cfg(feature = "std")]
     fn decastvf<T>(&mut self, slice: &[T], endian: Endian) -> Option<usize>
     where
 	T: Cast + Flip;
@@ -140,7 +161,7 @@ impl DecastMem for [u8]
 	}
     }
 
-    fn decastv<T>(&mut self, slice: &[T]) -> Option<usize>
+    fn decasts<T>(&mut self, slice: &[T]) -> Option<usize>
     where
 	T: Cast
     {
@@ -155,12 +176,12 @@ impl DecastMem for [u8]
 	Some(bytes.len())
     }
 
-    fn decastvf<T>(&mut self, slice: &[T], endian: Endian) -> Option<usize>
+    fn decastsf<T>(&mut self, slice: &[T], endian: Endian) -> Option<usize>
     where
 	T: Cast + Flip
     {
 	if !endian.need_swap() {
-	    self.decastv(slice)
+	    self.decasts(slice)
 	} else {
 	    let bytes = self.get_mut(0 .. mem::size_of::<T>() * slice.len())?;
 	    let mut off = 0;
@@ -171,4 +192,20 @@ impl DecastMem for [u8]
 	    Some(off)
 	}
     }
+
+    #[cfg(feature = "std")]
+    fn decastv<T>(&mut self, slice: &[T]) -> Option<usize>
+    where
+	T: Cast
+    {
+	self.decasts(slice)
+    }
+
+    #[cfg(feature = "std")]
+    fn decastvf<T>(&mut self, slice: &[T], endian: Endian) -> Option<usize>
+    where
+	T: Cast + Flip
+    {
+	self.decastsf(slice, endian)
+    }
 }
